==> orange_dam-1.2.1.tar.gz: orange_dam/src/OrangeDamQueueDataManagerInterface.php <==
<?php

namespace Drupal\orange_dam;

use Drupal\Core\Datetime\DrupalDateTime;

/**
 * Manages retrieving a list of updated content and building a queue.
 */
interface OrangeDamQueueDataManagerInterface {

  /**
   * Update the list of items that Orange DAM has new information for.
   *
   * @param \Drupal\Core\Datetime\DrupalDateTime|null $time_updated_since
   *   The time to check for updates since. Defaults to the last time ran.
   *
   * @return int|false
   *   The number of items queued for syncing or false on failure.
   */
  public function queueUpdatedItems(DrupalDateTime $time_updated_since = NULL);

  /**
   * Update single item from Orange DAM.
   *
   * @param string $system_identifier
   *   The unique ID of the item in Orange DAM. Example: EX1STO431061.
   *
   * @return \Drupal\orange_dam\OrangeDamItemInterface|false
   *   The item or false if the operation failed.
   */
  public function updateSingleItem(string $system_identifier);

  /**
   * Update the list of keywords that Orange DAM has new information for.
   *
   * @param \Drupal\Core\Datetime\DrupalDateTime|null $time_updated_since
   *   The time to check for updates since. Defaults to the last time ran.
   *
   * @return int|false
   *   The number of keywords queued for syncing or false on failure.
   */
  public function queueUpdatedKeywords(DrupalDateTime $time_updated_since = NULL);

  /**
   * Finds and deletes all items deleted since a given time.
   *
   * @param \Drupal\Core\Datetime\DrupalDateTime|null $time_deleted_since
   *   The time to check for deleted items since. Defaults to the last time ran.
   *
   * @return int|false
   *   The number of items queued for deletion or false on failure.
   */
  public function queueContentDeletions(DrupalDateTime $time_deleted_since = NULL);

}

==> orange_dam-1.6.0.tar.gz: orange_dam/src/OrangeDamQueueDataManagerInterface.php <==
<?php

namespace Drupal\orange_dam;

use Drupal\Core\Datetime\DrupalDateTime;

/**
 * Manages retrieving a list of updated content and building a queue.
 */
interface OrangeDamQueueDataManagerInterface {

  /**
   * Update the list of items that Orange DAM has new information for.
   *
   * @param \Drupal\Core\Datetime\DrupalDateTime|null $timeUpdatedSince
   *   The time to check for updates since. Defaults to the last time ran.
   *
   * @return int|false
   *   The number of items queued for syncing or false on failure.
   */
  public function queueUpdatedItems(DrupalDateTime $timeUpdatedSince = NULL);

  /**
   * Update single item from Orange DAM.
   *
   * @param string $systemIdentifier
   *   The unique ID of the item in Orange DAM. Example: EX1STO431061.
   *
   * @return \Drupal\orange_dam\OrangeDamItemInterface|false
   *   The item or false if the operation failed.
   */
  public function updateSingleItem(string $systemIdentifier);

  /**
   * Update the list of keywords that Orange DAM has new information for.
   *
   * @param \Drupal\Core\Datetime\DrupalDateTime|null $timeUpdatedSince
   *   The time to check for updates since. Defaults to the last time ran.
   *
   * @return int|false
   *   The number of keywords queued for syncing or false on failure.
   */
  public function queueUpdatedKeywords(DrupalDateTime $timeUpdatedSince = NULL);

  /**
   * Finds and deletes all items deleted since a given time.
   *
   * @param \Drupal\Core\Datetime\DrupalDateTime|null $timeDeletedSince
   *   The time to check for deleted items since. Defaults to the last time ran.
   *
   * @return int|false
   *   The number of items queued for deletion or false on failure.
   */
  public function queueContentDeletions(DrupalDateTime $timeDeletedSince = NULL);

}
